---
title: Android Installation
description: Manually integrate Cloud Firestore into your Android application.
next: /firestore/usage/installation/ios
previous: /firestore/usage
---

# Android Manual Installation

The following steps are only required if you are using React Native without auto-linking (<= 0.59) or you need to manually integrate the library.

## 1. Add Firestore to Gradle Settings

Add the following to your projects `/android/settings.gradle` file:

```groovy
include ':@react-native-firebase_firestore'
project(':@react-native-firebase_firestore').projectDir = new File(rootProject.projectDir, '../node_modules/@react-native-firebase/firestore/android')
```

## 2. Add Firestore to App Gradle Dependencies

Add the React Native Firebase module dependency to your `/android/app/build.gradle` file:

```groovy
// ..
dependencies {
  // ..
  implementation project(':@react-native-firebase_firestore')
}
```

## 3. Add Firestore to Main Android Application:

Import and apply the React Native Firebase module package to your `/android/app/src/main/java/**/MainApplication.java` file:

```java
import io.invertase.firebase.firestore.ReactNativeFirebaseFirestorePackage;
```

Add the package to the registry:

````java
protected List<ReactPackage> getPackages() {
  return Arrays.asList(
    new MainReactPackage(),
    new ReactNativeFirebaseFirestorePackage(),
```// ..
````

In some scenarios, your Android build may fail with the `app:mergeDexDebug` error. This required that multidex is enabled
for your application. To learn more, read the [Enabling Multidex](/firestore/enabling-multidex) documentation.

## 4. Rebuild your project

Once the above steps have been completed, rebuild your Android project:

```bash
npx react-native run-android
```
